@@ -5,22 +5,12 @@ except ModuleNotFoundError:  # pragma: no cover
 
 from importlib.metadata import PackageNotFoundError
 
-from poetry.plugins.application_plugin import ApplicationPlugin
-
 from .command import DevVersionCommand
+from .plugin import DevVersionPlugin
 
-__all__ = ["DevVersionCommand", "__version__"]
+__all__ = ["DevVersionCommand", "DevVersionPlugin", "__version__"]
 
 try:
     __version__ = importlib_metadata.version(__name__)
 except PackageNotFoundError:
     __version__ = "0.1.0"
-
-
-def factory() -> DevVersionCommand:
-    return DevVersionCommand()
-
-
-class DevVersionPlugin(ApplicationPlugin):
-    def activate(self, application):
-        application.command_loader.register_factory("dev-version", factory)
